@@ -2021,6 +2021,8 @@ class LayeredDistributive(Distributive):
         self._makeDirectory(target)
         if not path.exists(self.diff_directory):
             self._makeDirectory(self.diff_directory)
+        if path.exists(self.workdir):
+            self._removeDirectory(self.workdir)
         if not path.exists(self.workdir):
             self._makeDirectory(self.workdir)
         self._mountToDirectory("none", target, mountopts=(
